@@ -1,3 +1,4 @@
+#!/usr/bin/env python
 import os, sys, string, argparse, re
 import numpy as np
 import pyqtgraph as pg
@@ -5,23 +6,24 @@ from PyQt5 import QtGui, QtCore
 from glob import glob
 from time import time
 from matplotlib import cm
-import matplotlib.pyplot as plt
+from matplotlib.colors import LinearSegmentedColormap as LSC
 
 pg.setConfigOption('leftButtonPan', False)
 
 
 def _mouseMoved(evt):
-    mousePoint = plt.vb.mapSceneToView(evt[0])
+    mousePoint = plow.vb.mapSceneToView(evt[0])
     label.setText("<span style='font-size: 14pt; color: white'> x=%-10.4f y=%-10.4f" %(mousePoint.x(), mousePoint.y()))
 
 
 def _getcmcolors(length, cmapname):
-    cmap_inds = np.linspace(0, 255, length).astype(np.uint8)
+    cmap_inds = np.linspace(5, 250, length).astype(np.uint8)
     try:
         cmapobj = getattr(cm, cmapname)
     except:
-        print('Defaulting to cmap jet')
-        cmapobj = getattr(cm, 'jet')
+        color = np.array([[0,255,255,255], [0, 0, 255, 255], [192,0,192,255], [255, 0, 0, 255], [255,255,0,255]])/255
+        cmapobj = LSC.from_list('default', color)
+        print('Using default colormap')
     return [tuple([int(255*j) for j in cmapobj(i)]) for i in cmap_inds]
 
 
@@ -86,11 +88,11 @@ def filelinescheck(lines):
 
 
 def get_xye(argfiles, label, romin=0, romax=10000):
-    argfiles = [glob('%s' %arg) for arg in argfiles  ]
+    argfiles = [glob(f'{arg}) for arg in argfiles  ]
     argfiles = sorted(set([j for i in argfiles for j in i]))
     names, data = [], []
     for ind, f in enumerate(argfiles):
-        print('%-4d. %s' %(ind, f), end='')
+        print(f'{ind:<4d}. {f}', end='')
         if os.path.isfile(f):
             with open(f, 'r') as fil:
                 lines = fil.readlines()
@@ -104,7 +106,7 @@ def get_xye(argfiles, label, romin=0, romax=10000):
                 print('Not enough data'); sys.exit(0)
             except ValueError: # empty file 2
                 print('Not enough data'); sys.exit(0)
-            print(': %d points' %(len(x)))
+            print(f': {len(x)} points')
             data.append([x,y,e])
             if '/' in f:
                 sep = '/'
@@ -123,15 +125,16 @@ def get_xye(argfiles, label, romin=0, romax=10000):
     return data, names
 
 
-def main():
+if __name__ == '__main__':
     t0 = time()
+
     parser = argparse.ArgumentParser(description='At least better than plotdata')
     parser.add_argument('datafiles', nargs='+', type=str,
                         help='String(s) passed to glob to look for plottable files')
     parser.add_argument('-l','--label', choices=['index','prefix','dir','full'],
                         default='prefix', help='Cut legend label at: \
                         index (0002), prefix (Cr2O3_98keV_x1200_0002), dir (Cr2O3/Cr2O3_98keV_x1200_0002),\
-                        full (/gz/data/id15/inhouse3/2018/ch5514/Cr2O3/Cr2O3_98keV_x1200_0002)')
+                        full (/data/id15/inhouse3/2018/ch5514/Cr2O3/Cr2O3_98keV_x1200_0002)')
     parser.add_argument('-t','--title', default=os.path.realpath('.').split('/')[-1], help='Window title')
     parser.add_argument('--every', default=1, type=int, help='Plot only every N-th input file')
     parser.add_argument('--rmin', default=0, type=int, help='Cut N lines at the beginning of each file')
@@ -140,21 +143,24 @@ def main():
                         help='If True, plot the difference between each curve and the N-th input curve. \
                               Default (no value) = 0 (first curve). To subtract mean use --diff -99. \
                               Error is propagated over the two curves.')
-    parser.add_argument('--cmap', type=str, default='rainbow', nargs='?', help='One of the available matplotlib cmaps')
+    parser.add_argument('--cmap', type=str, default='spectral', nargs='?', help='One of the available matplotlib cmaps')
+    parser.add_argument('--winsize', type=int, nargs=2, default=(1024,768), help='Plot window size in pixels as width and height. Default: 1024 768')
     args = parser.parse_args()
+
     data, names = get_xye(args.datafiles[::args.every], args.label, args.rmin, args.rmax)
     t1 = time(); print('getting data', np.round(t1-t0, 3), 's')
-#    app = QtGui.QApplication([])
+
+    ### define window
     app = pg.mkQApp()
-    win = pg.GraphicsWindow(title=args.title)
-#    plt = pg.plot(title=args.title)
+    win = pg.GraphicsLayoutWidget(title=args.title, show=True, size=args.winsize)
     label = pg.LabelItem(justify = "right")
     win.addItem(label)
-    plt = win.addPlot(row=1, col=0, name='p1')
-    plt.showGrid(True, True, 0.5)
-    proxy = pg.SignalProxy(plt.scene().sigMouseMoved, rateLimit=60, slot=_mouseMoved)
-    leg = plt.addLegend()
-    leg.autoAnchor(pg.Point(plt.width()*0.95,plt.height()*0.0))
+    ### define plot area
+    plow = win.addPlot(row=1, col=0, name='p1')
+    plow.showGrid(True, True, 0.5)
+    proxy = pg.SignalProxy(plow.scene().sigMouseMoved, rateLimit=60, slot=_mouseMoved)
+    leg = plow.addLegend()
+    leg.autoAnchor(pg.Point(plow.width()*0.95,plow.height()*0.0))
     t2 = time(); print('starting window', np.round(t2-t1, 3), 's')
     colors = _getcmcolors(len(data), args.cmap)
     for ii in range(len(data)):
@@ -167,17 +173,13 @@ def main():
             y = y-ysubtr
             if sum(e) != 0:
                 e = np.sqrt(e**2 + esubtr**2)
-#        li = plt.plot(x, y, pen=(ii,len(data)), name=names[ii])
         cpen = pg.mkPen(colors[ii], width=1.25)
         li = pg.PlotDataItem(x=x, y=y, pen=cpen, name=names[ii])
-        plt.addItem(li)
+        plow.addItem(li)
         if sum(e) != 0:
             err = pg.ErrorBarItem(x=x, y=y, top=e/2, bottom=e/2, beam=0.5*np.mean(np.diff(x)), pen=cpen) #(ii,len(data)))
-            plt.addItem(err)
+            plow.addItem(err)
     t3 = time(); print('plotting', np.round(t3-t2, 3), 's')
     if (sys.flags.interactive != 1) or not hasattr(QtCore, 'PYQT_VERSION'):
-#        QtGui.QApplication.instance().exec_()
         pg.mkQApp().instance().exec_()
 
-if __name__ == '__main__':
-    main()
